﻿/**
 * ImageViewerDeluxe替ImageViewer新增了重新設定座標和大小的功能 
 * 範例檔網址：http://www.moock.org/eas2/examples/.
 *
 * @author: Colin Moock
 * @version: 2.0.0
 */
class ImageViewerDeluxe extends ImageViewer {

  // 指定觀看器能否縮放大小
  // 以便符合影像尺寸的旗標。 
  private var showFullImage:Boolean = false;

  public function ImageViewerDeluxe (target:MovieClip, 
                                depth:Number, 
                                x:Number, 
                                y:Number, 
                                w:Number, 
                                h:Number,
                                borderThickness:Number,
                                borderColor:Number) { 

    super(target, depth, x, y, w, h, borderThickness, borderColor);
  }

  /**
  * 設定觀看器的座標
  *
  * @param   x  	觀看器的新水平座標。
  * @param   y		觀看器的新垂直座標。
  */
  public function setPosition (x:Number, y:Number):Void {
    container_mc._x = x;
    container_mc._y = y;
  }

  /**
  * 設定觀看器的尺寸（亦即，調整邊框和遮罩的大小）。
  *
  * @param   w		觀看器的新寬度，單位為像素。
  * @param   h		觀看器的新高度，單位為像素。
  */
  public function setSize (w:Number, h:Number):Void {
    createImageClipMask(w, h);
    createBorder(w, h);
    container_mc.image_mc.setMask(container_mc.mask_mc);
  }

  /**
  * 傳回包含載入影像的影片片段的寬度。
  */
  public function getImageWidth ():Number {
    return container_mc.image_mc._width;
  }

  /** 
  * 傳回包含載入影像的影片片段的高度。
  */
  public function getImageHeight ():Number {
    return container_mc.image_mc._height;
  }

  /**
  * 設定指出是否呈現整張圖像或者裁切圖像
  * 使它符合觀看器大小的旗標。
  *
  * @param   show   指出是否要縮放觀看器讓它
  *                 吻合圖像的大小
  */
  public function setShowFullImage(show:Boolean):Void {
    showFullImage = show;
  }

  /**
  * 傳回是否呈現整張圖像或者裁切圖像
  * 使它符合觀看器大小的旗標。
  */ 
  public function getShowFullImage():Boolean {
    return showFullImage;
  }

  /**
  * 調整觀看器的大小，
  * 來呈現整張圖像。 
  */ 
  public function scaleViewerToImage ():Void {
    setSize(getImageWidth(), getImageHeight());
  }

  /**
  * MovieClipLoader處理程式。由imageLoader在圖像載入完畢後觸發。
  * 覆寫ImageViewer.onLoadInit(  )，增加自動調整尺寸的功能。
  */
  public function onLoadInit (target:MovieClip):Void {
    super.onLoadInit(target);

    if (showFullImage) {
      scaleViewerToImage();
    }
  }

}